==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/General/streambrowser/translations/streambrowser_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Stream Browser</source>
        <translatorcomment>מעיין זרם</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="28"/>
        <source>Stream Browser Plugin</source>
        <translation>תוספת Stream Browser</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="49"/>
        <source>About Stream Browser Plugin</source>
        <translation>אודות תוספת Stream Browser</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>תוספת Stream Browser ‫Qmmp</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>This plugin allows to add stream from IceCast stream directory</source>
        <translation>תוספת זו מתירה לך להוסיף זרם מן מדור זרם של IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov ‫&lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>סינון:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>מועדפים</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>עדכן</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="51"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="52"/>
        <location filename="../streamwindow.cpp" line="70"/>
        <source>Genre</source>
        <translation>ז&apos;אנר</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="53"/>
        <location filename="../streamwindow.cpp" line="71"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="54"/>
        <location filename="../streamwindow.cpp" line="72"/>
        <source>Format</source>
        <translation>פורמט</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="126"/>
        <source>&amp;Add to favorites</source>
        <translation>הוסף אל &amp;מועדפים</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="127"/>
        <source>&amp;Add to playlist</source>
        <translation>הוסף אל &amp;רשימת השמעה</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="132"/>
        <source>&amp;Remove</source>
        <translation>הס&amp;ר</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="142"/>
        <source>Done</source>
        <translation>סיום</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="145"/>
        <location filename="../streamwindow.cpp" line="146"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="165"/>
        <source>Receiving</source>
        <translatorcomment>מקבל כעת</translatorcomment>
        <translation>קבלה</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/streambrowser/translations/streambrowser_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Stream Browser</source>
        <translatorcomment>מעלעל זרם</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="28"/>
        <source>Stream Browser Plugin</source>
        <translation>תוספת Stream Browser</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="49"/>
        <source>About Stream Browser Plugin</source>
        <translation>אודות תוספת Stream Browser</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>תוספת Stream Browser של Qmmp</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>This plugin allows to add stream from IceCast stream directory</source>
        <translation>תוספת זו מתירה לך להוסיף זרם מתוך מדור זרם של IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>סינון:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>מועדפים</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>עדכן</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="51"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="52"/>
        <location filename="../streamwindow.cpp" line="70"/>
        <source>Genre</source>
        <translation>ז׳אנר</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="53"/>
        <location filename="../streamwindow.cpp" line="71"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="54"/>
        <location filename="../streamwindow.cpp" line="72"/>
        <source>Format</source>
        <translation>פורמט</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="125"/>
        <source>&amp;Add to favorites</source>
        <translation>הוסף אל &amp;מועדפים</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="126"/>
        <source>&amp;Add to playlist</source>
        <translation>הוסף אל &amp;רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="131"/>
        <source>&amp;Remove</source>
        <translation>הס&amp;ר</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="141"/>
        <source>Done</source>
        <translation>סיום</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="144"/>
        <location filename="../streamwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="164"/>
        <source>Receiving</source>
        <translatorcomment>מקבל כעת</translatorcomment>
        <translation>קבלה</translation>
    </message>
</context>
</TS>
